@@ -30,7 +30,7 @@ from shutil import rmtree
 from stat import ST_MODE, S_IXUSR, S_IXGRP, S_IXOTH
 from dhpython import MULTIARCH_DIR_TPL
 from dhpython.tools import fix_shebang, clean_egg_name
-from dhpython.interpreter import Interpreter
+from dhpython.interpreter import EXTFILE_RE, Interpreter
 
 log = logging.getLogger('dhpython')
 
@@ -98,6 +98,7 @@ def share_files(srcdir, dstdir, interpreter, options):
             # do not rename directories here - all .so files have to be renamed first
             os.renames(fpath1, fpath2)
             continue
+        ext_m = EXTFILE_RE.search(i)
         if islink(fpath1):
             # move symlinks without changing them if they point to the same place
             if not exists(fpath2):
@@ -108,7 +109,7 @@ def share_files(srcdir, dstdir, interpreter, options):
             share_files(fpath1, fpath2, interpreter, options)
         elif cmpfile(fpath1, fpath2, shallow=False):
             os.remove(fpath1)
-        elif i.endswith(('.abi3.so', '.abi4.so')) and interpreter.parse_public_dir(srcdir):
+        elif ext_m and ext_m.group("stableabi") and interpreter.parse_public_dir(srcdir):
             log.warning('%s differs from previous one, removing anyway (%s)', i, srcdir)
             os.remove(fpath1)
         elif srcdir.endswith(".dist-info"):
@@ -302,8 +303,13 @@ class Scan:
                 if fext == 'so':
                     if not self.options.no_ext_rename:
                         fpath = self.rename_ext(fpath, interpreter, version)
-                    ver = self.handle_ext(fpath)  # pylint: disable=assignment-from-none
-                    ver = ver or version
+                    ver = version
+                    # This is a bit of a hack, to fix #1121868.
+                    # Stop one .abi3.so in a package from loosening the
+                    # package's dependencies. Possibly we should be dealing
+                    # with this closer to the source.
+                    if ver == '3':
+                        ver = None
                     if ver:
                         self.current_result.setdefault('ext_vers', set()).add(ver)
                     else:
@@ -420,11 +426,6 @@ class Scan:
             return new_fpath
         return fpath
 
-    def handle_ext(self, fpath):
-        """Handle .so file, return its version if detected."""
-        # pylint: disable=unused-argument
-        return None
-
     def is_bin_dir(self, dpath):
         """Check if dir is one from PATH ones."""
         # dname = debian/packagename/usr/games
